@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Base.py,v 1.7 2000/03/03 15:44:26 fredgo Exp $
+# $Id: Base.py,v 1.8 2000/03/15 08:36:31 fredgo Exp $
 
 from string import *
 import re, copy, os
@@ -203,6 +203,11 @@ class DataBase:
 	return entry
 
 
+    def new_entry (self, type):
+        ''' Creates a new entry of the native type of the database '''
+        return Entry (None, type)
+    
+
     def keys (self):
 	''' Returns a list of all the keys available for the database '''
 
