@@ -1,6 +1,6 @@
 # This file is part of pybliographer
 # 
-# Copyright (C) 1998 Frederic GOBRY
+# Copyright (C) 1998,1999,2000 Frederic GOBRY
 # Email : gobry@idiap.ch
 # 	   
 # This program is free software; you can redistribute it and/or
@@ -17,9 +17,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Fields.py,v 1.1.1.1 1999/11/22 13:29:30 fredgo Exp $
+# $Id: Fields.py,v 1.7 2000/03/13 13:43:10 fredgo Exp $
 
-import string, types, re, string, recode
+from Pyblio import Key, Exceptions
+
+import string, types, re, string, recode, urlparse, os, gettext, time
+
+import copy, re
+_ = gettext.gettext
 
 year_match = re.compile ('(\d\d\d\d)')
 
@@ -34,43 +39,15 @@ def get_formatter (format):
     if formatter_cache.has_key (format):
         ft = formatter_cache [format]
     else:
-        ft = recode.recode ("latin1.." + format)
+        ft = recode.recode ('latin1..' + format)
         formatter_cache [format] = ft
 
     return ft
 
 
-class Access:
-    ''' virtual class used to check if instance attributes have been
-    modified '''
-    
-    def __init__ (self):
-        self.clean ()
-        return
-
-    def __setattr__ (self, attr, value):
-        if attr == '_modified_':
-            raise AttributeError, "can't modify _modified_"
-        
-        self.__dict__ [attr] = value
-        self.touch ()
-        return
-
-    def modified (self):
-        return self._modified_
-
-    def clean (self):
-        self.__dict__ ['_modified_'] = 0
-        return
-
-    def touch (self):
-        self.__dict__ ['_modified_'] = 1
-        return
-
-
-class Author (Access):
+class Author:
     ''' Fine description of an author '''
-    
+
     def __init__ (self, copy = None, strict = 0):
         ''' Initialize an author from a string or an other Author '''
 
@@ -137,12 +114,10 @@ class Author (Access):
                 self.lineage   = None
 
         self.text = None
-
-        Access.__init__ (self)
         return
 
 
-    def format (self, fmt):
+    def format (self, fmt = 'latin1'):
         ''' Returns the fields in a given format '''
         
         ft = get_formatter (fmt)
@@ -154,21 +129,19 @@ class Author (Access):
     def __str__ (self):
         ''' Returns textual representation '''
 
-        changed = self.modified ()
-        if changed or not self.text:
-            text = ""
-            if self.honorific: text = text + " " + self.honorific
-            if self.first:     text = text + " " + self.first
-            if self.last:      text = text + " " + self.last
-            if self.lineage:   text = text + ", " + self.lineage
+        if not self.text:
+            text = ''
+            if self.honorific: text = text + ' ' + self.honorific
+            if self.last:      text = text + ' ' + self.last
+            if self.lineage:   text = text + ', ' + self.lineage
+            if self.first:     text = text + ', ' + self.first
             self.text = text [1:]
-            if not changed: self.clean ()
             
         return self.text
 
 
     def __repr__ (self):
-        return "Author ((%s, %s, %s, %s))" % (`self.honorific`, `self.first`,
+        return 'Author ((%s, %s, %s, %s))' % (`self.honorific`, `self.first`,
                                               `self.last`, `self.lineage`)
 
 
@@ -217,12 +190,11 @@ class Author (Access):
         return 0
 
 
-class AuthorGroup (Access):
+class AuthorGroup:
     ''' A group of Authors '''
 
     def __init__ (self):
         self.authors = []
-        Access.__init__ (self)
         return
 
     def __getitem__ (self, pos):
@@ -236,27 +208,17 @@ class AuthorGroup (Access):
     def __len__ (self):
         return len (self.authors)
 
-    def modified (self):
-        for a in self.authors:
-            if a.modified (): return 1
-        return 0
-
-    def clean (self):
-        for a in self.authors:
-            a.clean ()
-        return
-    
     def append (self, value):
         self.authors.append (value)
         
     def __str__ (self):
-        return string.join (map (str, self.authors), ", ")
+        return string.join (map (str, self.authors), '; ')
 
     def __repr__ (self):
         return `self.authors`
 
     def match (self, regex):
-        return regex.search (string.join (map (str, self.authors), " "))
+        return regex.search (string.join (map (str, self.authors), ' '))
 
     def __cmp__ (self, other):
         i = 0
@@ -278,9 +240,8 @@ class AuthorGroup (Access):
 
         return 0
             
-RangeError = "RangeError"
 
-class Date (Access):
+class Date:
     ''' Fine description of a date '''
 
     def __init__ (self, arg = (None, None, None)):
@@ -293,7 +254,7 @@ class Date (Access):
                 if g:
                     year = int (g.group (1))
                 else:
-                    raise ValueError, "can't parse `%s' as a date" % arg
+                    year = None
                 
             month = None
             day   = None
@@ -301,57 +262,61 @@ class Date (Access):
             year, month, day = arg
         
         if year and year < 0:
-            raise RangeError, "wrong year"
+            raise Exceptions.DateError (_("Illegal year value"))
         self.year = year
         
         if month and (month < 1 or month > 12):
-            raise RangeError, "wrong month"
+            raise Exceptions.DateError (_("Illegal month value"))
         self.month = month
         
         if day and (day < 1 or day > 31):
-            raise RangeError, "wrong day"
+            raise Exceptions.DateError (_("Illegal day value"))
         self.day = day
 
         self.text = None
-        Access.__init__ (self)
         return
 
+
     def __cmp__ (self, other):
 
-        # No date is no date !
-        if not self.year and not other.year: return 0
-
-        diff = (self.year or other.year) - (other.year or self.year)
-        if diff: return diff
-
-        # Same year
-        if not self.month and not other.month: return 0
-
-        diff = (self.month or other.month) - (other.month or self.month)
-        if diff: return diff
+        s = self.year  or -1
+        o = other.year or -1
         
-        # Same month
-        if not self.day and not other.day: return 0
+        diff = s - o
+        if diff: return diff
+
+        s = self.month  or -1
+        o = other.month or -1
+        
+        diff = s - o
+        if diff: return diff
+
+        s = self.day  or -1
+        o = other.day or -1
+        
+        return s - o
 
-        return (self.day or other.day) - (other.day or self.day)
 
     def __str__ (self):
         ''' Returns textual representation '''
-        changed = self.modified ()
 
-        if changed or not self.text:
+        if not self.text:
             if self.year and self.month and self.day:
-                self.text = "%d/%d/%d" % (self.day, self.month, self.year)
+                self.text = '%d/%d/%d' % (self.day, self.month, self.year)
 
-            if self.year and self.month:
-                self.text = "%d/%d" % (self.month, self.year)
-            
-            self.text = str (self.year)
-            if not changed: self.clean ()
+            elif self.year and self.month:
+                self.text = '%d/%d' % (self.month, self.year)
             
+            elif self.year:
+                self.text = str (self.year)
+
+            else:
+                self.text = ''
+                
         return self.text
 
-    def format (self, fmt):
+
+    def format (self, fmt = 'latin1'):
         ''' Returns the fields in a given format '''
         ft = get_formatter (fmt)
 
@@ -371,7 +336,7 @@ class Date (Access):
 
     
     def __repr__ (self):
-        return str (self)
+        return 'Date (\'%s\')' % str (self)
 
 
     def match (self, regex):
@@ -379,15 +344,11 @@ class Date (Access):
         return regex.search (str (self))
         
 
-class Text (Access):
-    '''
-    This class holds all the other fields (not an Author or a Date)
-    '''
-    
+class Text:
+    ''' This class holds all the other fields (not an Author or a Date) '''
+
     def __init__ (self, text):
         self.text = text
-
-        Access.__init__ (self)
         return
 
 
@@ -396,7 +357,7 @@ class Text (Access):
 
 
     def __repr__ (self):
-        return "Text (%s)" % `self.text`
+        return 'Text (%s)' % `self.text`
 
 
     def match (self, regex):
@@ -408,8 +369,96 @@ class Text (Access):
         return cmp (self.text, str (other))
 
 
-    def format (self, fmt):
+    def format (self, fmt = 'latin1'):
         ''' Returns the fields in a given format '''
         ft = get_formatter (fmt)
 
         return ft (self.text)
+
+
+class URL:
+    ''' Holder for URL data (for example, the location of a database) '''
+
+    def __init__ (self, url):
+
+        if type (url) is types.StringType:
+            url = list (urlparse.urlparse (url))
+
+        if url [0] == '':
+            # Consider we handle a local file
+            url [0] = 'file'
+            url [2] = os.path.expanduser (url [2])
+            
+            if not os.path.isabs (url [2]):
+                url [2] = os.path.normpath (os.path.join (os.getcwd(), url [2]))
+
+        self.url = tuple (url)
+        return
+
+    def __cmp__ (self, other):
+        return cmp (self.url, other.url)
+
+    def __hash__ (self):
+        return hash (str (self))
+
+    def __str__ (self):
+        return urlparse.urlunparse (self.url)
+    
+
+    def __repr__ (self):
+        return 'URL (%s)' % `urlparse.urlunparse (self.url)`
+    
+
+class Reference:
+    ''' Holder for a reference to a bibliographic entry (which can be
+    a crossref, a link to related entries, ... '''
+
+    def __init__ (self, keylist, database = None):
+        
+        if type (keylist) is types.StringType:
+            self.list = map (lambda k, db = database: Key.Key (db, string.strip (k)),
+                             string.split (keylist, ','))
+        else:
+            self.list = keylist
+        return
+    
+    def __str__ (self):
+        body = []
+        # get the list of databases
+        dbs = {}
+        for refs in self.list:
+            dbs [refs.base] = 1
+
+        for db in dbs.keys ():
+            keys = []
+            for refs in self.list:
+                if refs.base == db:
+                    keys.append (refs.key)
+            body.append ('(' + string.join (keys, ', ') + ') ' +
+                         _("in %s") % db)
+        
+        return 'Reference on %s' % string.join (body, ', ')
+
+
+    def __repr__ (self):
+        return 'Reference (%s)' % `self.list`
+
+
+    def match (self, regex):
+        '''   '''
+        for key in self.list:
+            ret = regex.search (str (key))
+            if ret: return ret
+        return None
+
+
+    def __cmp__ (self, other):
+        return cmp (self.list, other.list)
+
+
+    def format (self, fmt = 'latin1'):
+        ''' Returns the fields in a given format '''
+        ft = get_formatter (fmt)
+
+        return map (ft, self.list)
+
