@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Document.py,v 1.8 2000/03/14 16:05:36 fredgo Exp $
+# $Id: Document.py,v 1.9 2000/03/15 08:36:32 fredgo Exp $
 
 ''' This module defines a Document class '''
 
@@ -433,7 +433,7 @@ class Document (Connector.Publisher):
     
     
     def add_entry (self, * arg):
-        entry = Base.Entry (None, Config.get ('base/defaulttype').data)
+        entry = self.data.new_entry (Config.get ('base/defaulttype').data)
         
         edit = Editor.Editor (self.data, entry, self.w)
         edit.Subscribe ('commit-edition', self.commit_edition)
