@@ -1,6 +1,6 @@
 # This file is part of pybliographer
 # 
-# Copyright (C) 1998 Frederic GOBRY
+# Copyright (C) 1998,1999,2000 Frederic GOBRY
 # Email : gobry@idiap.ch
 # 	   
 # This program is free software; you can redistribute it and/or
@@ -17,30 +17,34 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: FieldsInfo.py,v 1.1.1.1 1999/11/22 13:29:31 fredgo Exp $
+# $Id: FieldsInfo.py,v 1.3 2000/03/13 13:43:58 fredgo Exp $
 
 from Pyblio import Config
 import string
 
-WidgetText   = 0
-WidgetEntry  = 1
-WidgetAuthor = 2
-WidgetDate   = 3
 
-class UIDescription:
-    def __init__ (self, width, type):
-        self.width = width
-        self.type  = type
-        return
-
-def fieldinfo (field):
-    ht = Config.get ('gnomeui/fields').data
+def width (field):
+    ''' return the graphical width of a field given its name '''
+    
+    ht = Config.get ('base/fields').data
 
     field = string.lower (field)
     
-    if ht.has_key (field):
-        return ht [field]
+    if ht.has_key (field) and hasattr (ht [field], 'width'):
+        return ht [field].width
     else:
-        return Config.get ('gnomeui/default').data
+        return Config.get ('gnomeui/default').data [0]
 
+
+def widget (field):
+    ''' returns the representative widget of a field '''
+    
+    ht = Config.get ('base/fields').data
+
+    field = string.lower (field)
+    
+    if ht.has_key (field) and hasattr (ht [field], 'widget'):
+        return ht [field].widget
+    else:
+        return Config.get ('gnomeui/default').data [1]
         
