@@ -1,6 +1,6 @@
 # This file is part of pybliographer
 # 
-# Copyright (C) 1998 Frederic GOBRY
+# Copyright (C) 1998,1999,2000 Frederic GOBRY
 # Email : gobry@idiap.ch
 # 	   
 # This program is free software; you can redistribute it and/or
@@ -17,58 +17,54 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Utils.py,v 1.5 1999/09/27 15:56:24 gobry Exp $
+# $Id: Utils.py,v 1.4 2000/03/13 13:43:58 fredgo Exp $
 
 from gtk import *
 from gnome.ui import *
 
 from Pyblio import Config
 
-tooltips = GtkTooltips ()
+import gettext
+_ = gettext.gettext
 
-if Config.get ("gnomeui/tooltips").data:
-    tooltips.enable ()
-else:
-    tooltips.disable ()
 
 cursor = {}
 cursor ['clock']  = cursor_new (150)
 cursor ['normal'] = cursor_new (68)
 
 def set_cursor (self, name):
-    if not Config.get ("gnomeui/threads").data: return
 
-    self.get_window ().set_cursor (cursor [name])
-        
-    # not necessary with Gtk+-1.2.5
-    # threads_leave ()
+    window = self.get_window ()
+    if not window: return
     
+    window.set_cursor (cursor [name])
+        
     while events_pending ():
         mainiteration (FALSE)
-    
-    # not necessary with Gtk+-1.2.5
-    # threads_enter ()
     return
 
 def popup_add (menu, item, action = None, argument = None):
-    """ Helper to add a new menu entry """
+    ''' Helper to add a new menu entry '''
     
     tmp = GtkMenuItem (item)
     if action:
-        tmp.connect ("activate", action, argument)
+        tmp.connect ('activate', action, argument)
     
     tmp.show ()
     menu.append (tmp)
     
     return tmp
 
-def error_dialog (title, err):
+def error_dialog (title, err, parent = None):
     dialog = GnomeDialog (title, STOCK_BUTTON_CLOSE)
     dialog.button_connect (1, GnomeDialog.close)
     dialog.set_usize (500, 300)
-            
+    
+    if parent:
+        dialog.set_parent (parent)
+        
     text = GtkText ()
-    text.insert_defaults ("The following errors occured:\n\n")
+    text.insert_defaults (_("The following errors occured:\n\n"))
     text.insert (None, color ['red'], None, str (err))
     
     holder = GtkScrolledWindow ()
@@ -84,10 +80,28 @@ def error_dialog (title, err):
 color = {}
 
 def init_colors (colormap):
+    if color: return
+    
     color [' colormap '] = colormap
     
-    color ['red']  = colormap.alloc ("red")
-    color ['blue'] = colormap.alloc ("blue")
+    color ['red']  = colormap.alloc ('red')
+    color ['blue'] = colormap.alloc ('blue')
     return
 
 
+class Callback:
+    def __init__ (self, question, parent = None):
+        self.ans = 0
+
+        dialog = GnomeQuestionDialog (question, self.callback, parent = parent)
+        dialog.connect ('delete_event', mainquit)
+        return
+
+    def answer (self):
+        mainloop ()
+        return self.ans
+
+    def callback (self, button):
+        self.ans = button == 0
+        mainquit ()
+        return
