@@ -1,6 +1,6 @@
 # This file is part of pybliographer
 # 
-# Copyright (C) 1998 Frederic GOBRY
+# Copyright (C) 1998,1999,2000 Frederic GOBRY
 # Email : gobry@idiap.ch
 # 	   
 # This program is free software; you can redistribute it and/or
@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Utils.py,v 1.1.1.1 1999/11/22 13:29:32 fredgo Exp $
+# $Id: Utils.py,v 1.2 2000/02/23 10:21:54 fredgo Exp $
 
 """ This module contains several functions that can ease the work of
 describing a new bibliographic style """
@@ -26,11 +26,12 @@ import string
 
 from Pyblio import recode
 
-def author_desc (group, coding, initials = 0):
+def author_desc (group, coding, initials = 0, reverse = 0):
     """ Create a nice string describing a group of authors.
 
     	coding   : name of the output coding (as requested for recode)
         initials : if = 1, uses initials instead of complete first names
+        reverse  : use Last, First for all the authors, not only the first
     """
     
     l = len (group)
@@ -44,10 +45,15 @@ def author_desc (group, coding, initials = 0):
             first = group [i].initials (coding)
 
         text = ""
-        
-        if first:   text = first + " "
-        if last:    text = text + last
-        if lineage: text = text + ", " + lineage
+
+        if i == 0 or reverse:
+            if last:    text = text + last
+            if lineage: text = text + ", " + lineage
+            if first:   text = text + ", " + first
+        else:
+            if first:   text = first + " "
+            if last:    text = text + last
+            if lineage: text = text + ", " + lineage
 
         if text:
             if i < l - 2:
