@@ -18,7 +18,7 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: bibtexmodule.c,v 1.1.1.1 1999/11/22 13:29:32 fredgo Exp $
+ $Id: bibtexmodule.c,v 1.3 2000/02/23 10:25:13 fredgo Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -115,7 +115,7 @@ py_message_handler (const gchar *log_domain G_GNUC_UNUSED,
 }
 
 static PyObject *
-bib_open (PyObject * self, PyObject * args)
+bib_open_file (PyObject * self, PyObject * args)
 {
     char * name;
     BibtexSource * file;
@@ -144,6 +144,36 @@ bib_open (PyObject * self, PyObject * args)
     return (PyObject *) ret;
 }
 
+static PyObject *
+bib_open_string (PyObject * self, PyObject * args)
+{
+    char * name, * string;
+    BibtexSource * file;
+    gint strictness;
+
+    PyBibtexSource_Object * ret;
+
+    if (! PyArg_ParseTuple(args, "ssi", & name, & string, & strictness))
+	return NULL;
+
+    file = bibtex_source_new ();
+
+    /* set the strictness */
+    file->strict = strictness;
+
+    if (! bibtex_source_string (file, name, string)) {
+	bibtex_source_destroy (file, TRUE);
+	return NULL;
+    }
+
+    /* Create a new object */
+    ret = (PyBibtexSource_Object *) 
+	PyObject_NEW (PyBibtexSource_Object, & PyBibtexSource_Type);
+    ret->obj = file;
+
+    return (PyObject *) ret;
+}
+
 static PyObject *
 bib_expand (PyObject * self, PyObject * args) {
     PyObject * liste, * tmp, * auth [4];
@@ -274,6 +304,25 @@ bib_get_native (PyObject * self, PyObject * args) {
     return tmp;
 }
 
+static PyObject *
+bib_copy_field (PyObject * self, PyObject * args) {
+    BibtexField * field, * copy;
+    PyBibtexField_Object * field_obj, * new_obj;
+    gchar * text;
+    int i;
+
+    if (! PyArg_ParseTuple(args, "O!:get_native", & PyBibtexField_Type, & field_obj))
+	return NULL;
+
+    field = field_obj->obj;
+
+    new_obj = (PyBibtexField_Object *) PyObject_NEW (PyBibtexField_Object, & PyBibtexField_Type);
+
+    new_obj->obj = bibtex_struct_as_field (bibtex_struct_copy (field->structure), field->type);
+
+    return (PyObject *) new_obj;
+}
+
 static PyObject *
 bib_get_latex (PyObject * self, PyObject * args) {
     PyObject * tmp;
@@ -387,6 +436,36 @@ fill_struct_dico (gpointer key, gpointer value, gpointer user)
     Py_DECREF (tmp2);
 }
 
+static PyObject *
+bib_set_string (PyObject * self, PyObject * args)
+{
+    BibtexField * field;
+    BibtexSource * source;
+    PyBibtexSource_Object * source_obj;
+    PyBibtexField_Object * field_obj;
+    
+    gchar * key;
+
+    if (! PyArg_ParseTuple(args, "O!sO!:set_string", 
+			   & PyBibtexSource_Type, 
+			   & source_obj,
+			   & key,
+			   & PyBibtexField_Type,
+			   & field_obj
+			   ))
+	return NULL;
+
+    source = source_obj->obj;
+    field  = field_obj->obj;
+
+    /* set a copy of the struct as the field value */
+    bibtex_source_set_string (source, key, 
+			      bibtex_struct_copy (field->structure));
+
+    Py_INCREF (Py_None);
+    return Py_None;
+}
+
 
 static PyObject *
 bib_next (PyObject * self, PyObject * args)
@@ -530,7 +609,6 @@ bib_reverse (PyObject * self, PyObject * args)
 	    tmp = PyObject_GetAttrString (authobj, "last");
 	    if (tmp != Py_None) {
 		auth->last = g_strdup (PyString_AsString (tmp));
-/*  		g_message ("last: %s", auth->last); */
 	    }
 	    else {
 		auth->last = NULL;
@@ -539,7 +617,6 @@ bib_reverse (PyObject * self, PyObject * args)
 	    tmp = PyObject_GetAttrString (authobj, "first");
 	    if (tmp != Py_None) {
 		auth->first = g_strdup (PyString_AsString (tmp));
-/*  		g_message ("first: %s %x", auth->first, auth->first); */
 	    }
 	    else {
 		auth->first = NULL;
@@ -616,7 +693,8 @@ bib_get_offset (PyObject * self, PyObject * args)
 
 
 static PyMethodDef bibtexMeth [] = {
-    { "open", bib_open, METH_VARARGS },
+    { "open_file", bib_open_file, METH_VARARGS },
+    { "open_string", bib_open_string, METH_VARARGS },
     { "next", bib_next, METH_VARARGS },
     { "first", bib_first, METH_VARARGS },
     { "set_offset", bib_set_offset, METH_VARARGS },
@@ -627,6 +705,8 @@ static PyMethodDef bibtexMeth [] = {
     { "set_native", bib_set_native, METH_VARARGS },
     { "reverse", bib_reverse, METH_VARARGS },
     { "get_dict", bib_get_dict, METH_VARARGS },
+    { "set_string", bib_set_string, METH_VARARGS },
+    { "copy_field", bib_copy_field, METH_VARARGS },
     {NULL, NULL, 0},
 };
 
